@@ -40,6 +40,7 @@ class GraphSage(Dataset):
 
     - `name`: name of the dataset to load (`'ppi'`, or `'reddit'`);
     """
+
     # TODO normalize features?
     # # # Z-score on features (optional)
     # if normalize_features:
@@ -51,39 +52,42 @@ class GraphSage(Dataset):
     #     scaler.fit(x_tr)
     #     x = scaler.transform(x)
 
-    url = 'http://snap.stanford.edu/graphsage/{}.zip'
+    url = "http://snap.stanford.edu/graphsage/{}.zip"
 
     def __init__(self, name, **kwargs):
         if name.lower() not in self.available_datasets:
-            raise ValueError('Unknown dataset: {}. Possible: {}'
-                             .format(name, self.available_datasets))
+            raise ValueError(
+                "Unknown dataset: {}. Possible: {}".format(
+                    name, self.available_datasets
+                )
+            )
         self.name = name.lower()
         self.mask_tr = self.mask_va = self.mask_te = None
         super().__init__(**kwargs)
 
     @property
     def path(self):
-        return osp.join(DATASET_FOLDER, 'GraphSage', self.name)
+        return osp.join(DATASET_FOLDER, "GraphSage", self.name)
 
     def read(self):
-        npz_file = osp.join(self.path, self.name) + '.npz'
+        npz_file = osp.join(self.path, self.name) + ".npz"
         data = np.load(npz_file)
-        x = data['x']
+        x = data["x"]
         a = sp.csr_matrix(
-            (data['adj_data'], (data['adj_row'], data['adj_col'])),
-            shape=data['adj_shape']
+            (data["adj_data"], (data["adj_row"], data["adj_col"])),
+            shape=data["adj_shape"],
         )
-        y = data['y']
-        self.mask_tr = data['mask_tr']
-        self.mask_va = data['mask_va']
-        self.mask_te = data['mask_te']
+        y = data["y"]
+        self.mask_tr = data["mask_tr"]
+        self.mask_va = data["mask_va"]
+        self.mask_te = data["mask_te"]
 
         return [Graph(x=x, a=a, y=y)]
 
     def download(self):
-        print('Downloading {} dataset.'.format(self.name))
+        print("Downloading {} dataset.".format(self.name))
         url = self.url.format(self.name)
-        download_file(url, self.path, self.name + '.zip')
+        download_file(url, self.path, self.name + ".zip")
 
         # Datasets are zipped in a folder: unpack them
         parent = self.path
@@ -95,38 +99,49 @@ class GraphSage(Dataset):
         x, adj, y, mask_tr, mask_va, mask_te = preprocess_data(self.path, self.name)
 
         # Save pre-processed data
-        npz_file = osp.join(self.path, self.name) + '.npz'
+        npz_file = osp.join(self.path, self.name) + ".npz"
         adj = adj.tocoo()
-        np.savez(npz_file, x=x, adj_data=adj.data, adj_row=adj.row,
-                 adj_col=adj.col, adj_shape=adj.shape, y=y,
-                 mask_tr=mask_tr, mask_va=mask_va, mask_te=mask_te)
+        np.savez(
+            npz_file,
+            x=x,
+            adj_data=adj.data,
+            adj_row=adj.row,
+            adj_col=adj.col,
+            adj_shape=adj.shape,
+            y=y,
+            mask_tr=mask_tr,
+            mask_va=mask_va,
+            mask_te=mask_te,
+        )
 
     @property
     def available_datasets(self):
-        return ['ppi', 'reddit']
+        return ["ppi", "reddit"]
 
 
 class PPI(GraphSage):
     """
     Alias for `GraphSage('ppi')`.
     """
+
     def __init__(self, **kwargs):
-        super().__init__(name='ppi', **kwargs)
+        super().__init__(name="ppi", **kwargs)
 
 
 class Reddit(GraphSage):
     """
     Alias for `GraphSage('reddit')`.
     """
+
     def __init__(self, **kwargs):
-        super().__init__(name='reddit', **kwargs)
+        super().__init__(name="reddit", **kwargs)
 
 
 def preprocess_data(path, name):
     """
     Code adapted from https://github.com/williamleif/GraphSAGE
     """
-    print('Processing dataset.')
+    print("Processing dataset.")
     prefix = osp.join(path, name)
 
     G_data = json.load(open(prefix + "-G.json"))
@@ -153,12 +168,16 @@ def preprocess_data(path, name):
     [G.remove_node(node) for node in G.nodes() if node not in id_map]
 
     # Adjacency matrix
-    edges = [(id_map[edge[0]], id_map[edge[1]])
-             for edge in G.edges()
-             if edge[0] in id_map and edge[1] in id_map]
+    edges = [
+        (id_map[edge[0]], id_map[edge[1]])
+        for edge in G.edges()
+        if edge[0] in id_map and edge[1] in id_map
+    ]
     edges = np.array(edges, dtype=np.int32)
-    adj = sp.csr_matrix((np.ones((edges.shape[0]), dtype=np.float32),
-                         (edges[:, 0], edges[:, 1])), shape=(n, n))
+    adj = sp.csr_matrix(
+        (np.ones((edges.shape[0]), dtype=np.float32), (edges[:, 0], edges[:, 1])),
+        shape=(n, n),
+    )
     adj = adj.maximum(adj.transpose())
 
     # Process labels
@@ -174,8 +193,12 @@ def preprocess_data(path, name):
             y[id_map[k], class_map[k]] = 1
 
     # Get train/val/test indexes
-    idx_va = np.array([id_map[n] for n in G.nodes() if G.nodes[n]['val']], dtype=np.int32)
-    idx_te = np.array([id_map[n] for n in G.nodes() if G.nodes[n]['test']], dtype=np.int32)
+    idx_va = np.array(
+        [id_map[n] for n in G.nodes() if G.nodes[n]["val"]], dtype=np.int32
+    )
+    idx_te = np.array(
+        [id_map[n] for n in G.nodes() if G.nodes[n]["test"]], dtype=np.int32
+    )
     mask_tr = np.ones(n, dtype=np.bool)
     mask_va = np.zeros(n, dtype=np.bool)
     mask_te = np.zeros(n, dtype=np.bool)
