@@ -5,7 +5,7 @@ import zipfile
 import requests
 from tqdm import tqdm
 
-DATASET_FOLDER = osp.expanduser('~/.spektral/datasets')
+DATASET_FOLDER = osp.expanduser("~/.spektral/datasets")
 
 
 def download_file(url, datadir, fname, progress=True, extract=True):
@@ -13,10 +13,15 @@ def download_file(url, datadir, fname, progress=True, extract=True):
         r.raise_for_status()
         os.makedirs(datadir, exist_ok=True)
         outfile = osp.join(datadir, fname)
-        with open(outfile, 'wb') as of:
+        with open(outfile, "wb") as of:
             if progress:
-                pbar = tqdm(total=int(r.headers['Content-Length']), ncols=80,
-                            unit='B', unit_scale=True, unit_divisor=1024)
+                pbar = tqdm(
+                    total=int(r.headers["Content-Length"]),
+                    ncols=80,
+                    unit="B",
+                    unit_scale=True,
+                    unit_divisor=1024,
+                )
                 for chunk in r.iter_content(chunk_size=8192):
                     if chunk is not None:
                         of.write(chunk)
@@ -24,7 +29,7 @@ def download_file(url, datadir, fname, progress=True, extract=True):
             else:
                 of.write(r.content)
 
-    if extract and fname.endswith('.zip'):
-        with zipfile.ZipFile(outfile, 'r') as of:
+    if extract and fname.endswith(".zip"):
+        with zipfile.ZipFile(outfile, "r") as of:
             of.extractall(datadir)
         os.remove(outfile)
