@@ -1,6 +1,7 @@
 import tensorflow as tf
 from tensorflow.keras import backend as K
 
+import spektral.layers.ops.scatter
 from spektral.layers import ops
 from spektral.layers.convolutional.message_passing import MessagePassing
 
@@ -12,7 +13,7 @@ class AGNNConv(MessagePassing):
     > [Attention-based Graph Neural Network for Semi-supervised Learning](https://arxiv.org/abs/1803.03735)<br>
     > Kiran K. Thekumparampil et al.
 
-    **Mode**: single, disjoint.
+    **Mode**: single, disjoint, mixed.
 
     **This layer expects a sparse adjacency matrix.**
 
@@ -47,16 +48,16 @@ class AGNNConv(MessagePassing):
     - `activation`: activation function;
     """
 
-    def __init__(self, trainable=True, aggregate='sum', activation=None, **kwargs):
+    def __init__(self, trainable=True, aggregate="sum", activation=None, **kwargs):
         super().__init__(aggregate=aggregate, activation=activation, **kwargs)
         self.trainable = trainable
 
     def build(self, input_shape):
         assert len(input_shape) >= 2
         if self.trainable:
-            self.beta = self.add_weight(shape=(1,), initializer='ones', name='beta')
+            self.beta = self.add_weight(shape=(1,), initializer="ones", name="beta")
         else:
-            self.beta = K.constant(1.)
+            self.beta = K.constant(1.0)
         self.built = True
 
     def call(self, inputs, **kwargs):
@@ -72,13 +73,18 @@ class AGNNConv(MessagePassing):
         x_norm_i = self.get_i(x_norm)
         x_norm_j = self.get_j(x_norm)
         alpha = self.beta * tf.reduce_sum(x_norm_i * x_norm_j, axis=-1)
+
+        if len(tf.shape(alpha)) == 2:
+            alpha = tf.transpose(alpha)  # For mixed mode
         alpha = ops.unsorted_segment_softmax(alpha, self.index_i, self.n_nodes)
-        alpha = alpha[:, None]
+        if len(tf.shape(alpha)) == 2:
+            alpha = tf.transpose(alpha)  # For mixed mode
+        alpha = alpha[..., None]
 
         return alpha * x_j
 
     @property
     def config(self):
         return {
-            'trainable': self.trainable,
+            "trainable": self.trainable,
         }
