@@ -12,7 +12,7 @@ class CrystalConv(MessagePassing):
     Interpretable Prediction of Material Properties](https://arxiv.org/abs/1710.10324)<br>
     > Tian Xie and Jeffrey C. Grossman
 
-    **Mode**: single, disjoint.
+    **Mode**: single, disjoint, mixed.
 
     **This layer expects a sparse adjacency matrix.**
 
@@ -51,30 +51,34 @@ class CrystalConv(MessagePassing):
     - `bias_constraint`: constraint applied to the bias vector.
     """
 
-    def __init__(self,
-                 channels,
-                 aggregate='sum',
-                 activation=None,
-                 use_bias=True,
-                 kernel_initializer='glorot_uniform',
-                 bias_initializer='zeros',
-                 kernel_regularizer=None,
-                 bias_regularizer=None,
-                 activity_regularizer=None,
-                 kernel_constraint=None,
-                 bias_constraint=None,
-                 **kwargs):
-        super().__init__(aggregate=aggregate,
-                         activation=activation,
-                         use_bias=use_bias,
-                         kernel_initializer=kernel_initializer,
-                         bias_initializer=bias_initializer,
-                         kernel_regularizer=kernel_regularizer,
-                         bias_regularizer=bias_regularizer,
-                         activity_regularizer=activity_regularizer,
-                         kernel_constraint=kernel_constraint,
-                         bias_constraint=bias_constraint,
-                         **kwargs)
+    def __init__(
+        self,
+        channels,
+        aggregate="sum",
+        activation=None,
+        use_bias=True,
+        kernel_initializer="glorot_uniform",
+        bias_initializer="zeros",
+        kernel_regularizer=None,
+        bias_regularizer=None,
+        activity_regularizer=None,
+        kernel_constraint=None,
+        bias_constraint=None,
+        **kwargs
+    ):
+        super().__init__(
+            aggregate=aggregate,
+            activation=activation,
+            use_bias=use_bias,
+            kernel_initializer=kernel_initializer,
+            bias_initializer=bias_initializer,
+            kernel_regularizer=kernel_regularizer,
+            bias_regularizer=bias_regularizer,
+            activity_regularizer=activity_regularizer,
+            kernel_constraint=kernel_constraint,
+            bias_constraint=bias_constraint,
+            **kwargs
+        )
         self.channels = channels
 
     def build(self, input_shape):
@@ -85,9 +89,9 @@ class CrystalConv(MessagePassing):
             kernel_regularizer=self.kernel_regularizer,
             bias_regularizer=self.bias_regularizer,
             kernel_constraint=self.kernel_constraint,
-            bias_constraint=self.bias_constraint
+            bias_constraint=self.bias_constraint,
         )
-        self.dense_f = Dense(self.channels, activation='sigmoid', **layer_kwargs)
+        self.dense_f = Dense(self.channels, activation="sigmoid", **layer_kwargs)
         self.dense_s = Dense(self.channels, activation=self.activation, **layer_kwargs)
 
         self.built = True
@@ -95,7 +99,11 @@ class CrystalConv(MessagePassing):
     def message(self, x, e=None):
         x_i = self.get_i(x)
         x_j = self.get_j(x)
-        z = K.concatenate((x_i, x_j, e), axis=-1)
+
+        to_concat = [x_i, x_j]
+        if e is not None:
+            to_concat += [e]
+        z = K.concatenate(to_concat, axis=-1)
         output = self.dense_s(z) * self.dense_f(z)
 
         return output
@@ -105,6 +113,4 @@ class CrystalConv(MessagePassing):
 
     @property
     def config(self):
-        return {
-            'channels': self.channels
-        }
+        return {"channels": self.channels}
