@@ -12,7 +12,7 @@ class TAGConv(MessagePassing):
     > [Topology Adaptive Graph Convolutional Networks](https://arxiv.org/abs/1710.10370)<br>
     > Jian Du et al.
 
-    **Mode**: single, disjoint.
+    **Mode**: single, disjoint, mixed.
 
     **This layer expects a sparse adjacency matrix.**
 
@@ -47,43 +47,49 @@ class TAGConv(MessagePassing):
     - `bias_constraint`: constraint applied to the bias vector.
     """
 
-    def __init__(self,
-                 channels,
-                 K=3,
-                 aggregate='sum',
-                 activation=None,
-                 use_bias=True,
-                 kernel_initializer='glorot_uniform',
-                 bias_initializer='zeros',
-                 kernel_regularizer=None,
-                 bias_regularizer=None,
-                 activity_regularizer=None,
-                 kernel_constraint=None,
-                 bias_constraint=None,
-                 **kwargs):
-        super().__init__(aggregate=aggregate,
-                         activation=activation,
-                         use_bias=use_bias,
-                         kernel_initializer=kernel_initializer,
-                         bias_initializer=bias_initializer,
-                         kernel_regularizer=kernel_regularizer,
-                         bias_regularizer=bias_regularizer,
-                         activity_regularizer=activity_regularizer,
-                         kernel_constraint=kernel_constraint,
-                         bias_constraint=bias_constraint,
-                         **kwargs)
+    def __init__(
+        self,
+        channels,
+        K=3,
+        aggregate="sum",
+        activation=None,
+        use_bias=True,
+        kernel_initializer="glorot_uniform",
+        bias_initializer="zeros",
+        kernel_regularizer=None,
+        bias_regularizer=None,
+        activity_regularizer=None,
+        kernel_constraint=None,
+        bias_constraint=None,
+        **kwargs
+    ):
+        super().__init__(
+            aggregate=aggregate,
+            activation=activation,
+            use_bias=use_bias,
+            kernel_initializer=kernel_initializer,
+            bias_initializer=bias_initializer,
+            kernel_regularizer=kernel_regularizer,
+            bias_regularizer=bias_regularizer,
+            activity_regularizer=activity_regularizer,
+            kernel_constraint=kernel_constraint,
+            bias_constraint=bias_constraint,
+            **kwargs
+        )
         self.channels = channels
         self.K = K
-        self.linear = Dense(channels,
-                            activation=activation,
-                            use_bias=use_bias,
-                            kernel_initializer=kernel_initializer,
-                            bias_initializer=bias_initializer,
-                            kernel_regularizer=kernel_regularizer,
-                            bias_regularizer=bias_regularizer,
-                            activity_regularizer=activity_regularizer,
-                            kernel_constraint=kernel_constraint,
-                            bias_constraint=bias_constraint)
+        self.linear = Dense(
+            channels,
+            activation=activation,
+            use_bias=use_bias,
+            kernel_initializer=kernel_initializer,
+            bias_initializer=bias_initializer,
+            kernel_regularizer=kernel_regularizer,
+            bias_regularizer=bias_regularizer,
+            activity_regularizer=activity_regularizer,
+            kernel_constraint=kernel_constraint,
+            bias_constraint=bias_constraint,
+        )
 
     def build(self, input_shape):
         assert len(input_shape) >= 2
@@ -106,8 +112,8 @@ class TAGConv(MessagePassing):
 
     @property
     def config(self):
-        return{
-            'channels': self.channels,
+        return {
+            "channels": self.channels,
         }
 
     @staticmethod
