@@ -1,4 +1,4 @@
-from spektral.utils import one_hot, label_to_one_hot
+from spektral.utils import label_to_one_hot, one_hot
 
 
 class OneHotLabels(object):
@@ -15,11 +15,12 @@ class OneHotLabels(object):
     - `labels`: list or tuple, the possible values that the labels can take
     (labels are one-hot encoded according to where they are found in`labels`).
     """
+
     def __init__(self, depth=None, labels=None):
         self.depth = depth
         self.labels = labels
         if self.depth is None and self.labels is None:
-            raise ValueError('Must specify either depth or labels.')
+            raise ValueError("Must specify either depth or labels.")
 
     def __call__(self, graph):
         if self.labels is not None:
