@@ -1,13 +1,13 @@
 import numpy as np
 import tensorflow as tf
-from tensorflow.keras import Model, Input
+from tensorflow.keras import Input, Model
 
 from spektral import layers
 from spektral.layers.ops import sp_matrix_to_sp_tensor
 
-tf.keras.backend.set_floatx('float64')
+tf.keras.backend.set_floatx("float64")
 SINGLE, BATCH, MIXED = 1, 2, 3  # Single, batch, mixed
-LAYER_K_, MODES_K_, KWARGS_K_ = 'layer', 'modes', 'kwargs'
+LAYER_K_, MODES_K_, KWARGS_K_ = "layer", "modes", "kwargs"
 batch_size = 32
 N = 11
 F = 7
@@ -55,100 +55,145 @@ TESTS = [
     {
         LAYER_K_: layers.GCNConv,
         MODES_K_: [SINGLE, BATCH, MIXED],
-        KWARGS_K_: {'channels': 8, 'activation': 'relu', 'sparse': [False, True]},
+        KWARGS_K_: {
+            "channels": 8,
+            "activation": "relu",
+            "sparse_support": [False, True],
+        },
     },
     {
         LAYER_K_: layers.ChebConv,
         MODES_K_: [SINGLE, BATCH, MIXED],
-        KWARGS_K_: {'K': 3, 'channels': 8, 'activation': 'relu', 'sparse': [False, True]}
+        KWARGS_K_: {
+            "K": 3,
+            "channels": 8,
+            "activation": "relu",
+            "sparse_support": [False, True],
+        },
     },
     {
         LAYER_K_: layers.GraphSageConv,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': 8, 'activation': 'relu', 'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {"channels": 8, "activation": "relu", "sparse_support": [True]},
     },
     {
         LAYER_K_: layers.ECCConv,
-        MODES_K_: [SINGLE, BATCH],
-        KWARGS_K_: {'kernel_network': [8], 'channels': 8, 'activation': 'relu',
-                    'edges': True, 'sparse': [False, True]}
+        MODES_K_: [SINGLE, BATCH, MIXED],
+        KWARGS_K_: {
+            "kernel_network": [8],
+            "channels": 8,
+            "activation": "relu",
+            "edges": True,
+            "sparse_support": [False, True],
+        },
     },
     {
         LAYER_K_: layers.GATConv,
         MODES_K_: [SINGLE, BATCH, MIXED],
-        KWARGS_K_: {'channels': 8, 'attn_heads': 2, 'concat_heads': False,
-                    'activation': 'relu', 'sparse': [False, True]}
+        KWARGS_K_: {
+            "channels": 8,
+            "attn_heads": 2,
+            "concat_heads": False,
+            "activation": "relu",
+            "sparse_support": [False, True],
+        },
     },
     {
         LAYER_K_: layers.GCSConv,
         MODES_K_: [SINGLE, BATCH, MIXED],
-        KWARGS_K_: {'channels': 8, 'activation': 'relu', 'sparse': [False, True]}
+        KWARGS_K_: {
+            "channels": 8,
+            "activation": "relu",
+            "sparse_support": [False, True],
+        },
     },
     {
         LAYER_K_: layers.ARMAConv,
         MODES_K_: [SINGLE, BATCH, MIXED],
-        KWARGS_K_: {'channels': 8, 'activation': 'relu', 'order': 2, 'iterations': 2,
-                    'share_weights': True, 'sparse': [False, True]}
+        KWARGS_K_: {
+            "channels": 8,
+            "activation": "relu",
+            "order": 2,
+            "iterations": 2,
+            "share_weights": True,
+            "sparse_support": [False, True],
+        },
     },
     {
         LAYER_K_: layers.APPNPConv,
         MODES_K_: [SINGLE, BATCH, MIXED],
-        KWARGS_K_: {'channels': 8, 'activation': 'relu', 'mlp_hidden': [16],
-                    'sparse': [False, True]}
+        KWARGS_K_: {
+            "channels": 8,
+            "activation": "relu",
+            "mlp_hidden": [16],
+            "sparse_support": [False, True],
+        },
     },
     {
         LAYER_K_: layers.GINConv,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': 8, 'activation': 'relu', 'mlp_hidden': [16],
-                    'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {
+            "channels": 8,
+            "activation": "relu",
+            "mlp_hidden": [16],
+            "sparse_support": [True],
+        },
     },
     {
         LAYER_K_: layers.DiffusionConv,
         MODES_K_: [SINGLE, BATCH, MIXED],
-        KWARGS_K_: {'channels': 8, 'activation': 'tanh', 'num_diffusion_steps': 5,
-                    'sparse': [False]}
+        KWARGS_K_: {
+            "channels": 8,
+            "activation": "tanh",
+            "num_diffusion_steps": 5,
+            "sparse_support": [False],
+        },
     },
     {
         LAYER_K_: layers.GatedGraphConv,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': 10, 'n_layers': 3, 'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {"channels": 10, "n_layers": 3, "sparse_support": [True]},
     },
     {
         LAYER_K_: layers.AGNNConv,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': F, 'trainable': True, 'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {"channels": F, "trainable": True, "sparse_support": [True]},
     },
     {
         LAYER_K_: layers.TAGConv,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': F, 'K': 3, 'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {"channels": F, "K": 3, "sparse_support": [True]},
     },
     {
         LAYER_K_: layers.CrystalConv,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': F, 'edges': True, 'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {"channels": F, "edges": True, "sparse_support": [True]},
     },
     {
         LAYER_K_: layers.EdgeConv,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': 8, 'activation': 'relu', 'mlp_hidden': [16],
-                    'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {
+            "channels": 8,
+            "activation": "relu",
+            "mlp_hidden": [16],
+            "sparse_support": [True],
+        },
     },
     {
         LAYER_K_: layers.GeneralConv,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': 256, 'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {"channels": 256, "sparse_support": [True]},
     },
     {
         LAYER_K_: layers.MessagePassing,
-        MODES_K_: [SINGLE],
-        KWARGS_K_: {'channels': F, 'sparse': [True]}
+        MODES_K_: [SINGLE, MIXED],
+        KWARGS_K_: {"channels": F, "sparse_support": [True]},
     },
 ]
 
 
 def _test_single_mode(layer, **kwargs):
-    sparse = kwargs.pop('sparse', False)
+    sparse = kwargs.pop("sparse", False)
     A_in = Input(shape=(None,), sparse=sparse)
     X_in = Input(shape=(F,))
     inputs = [X_in, A_in]
@@ -157,8 +202,8 @@ def _test_single_mode(layer, **kwargs):
     else:
         input_data = [X, A]
 
-    if kwargs.pop('edges', None):
-        E_in = Input(shape=(S, ))
+    if kwargs.pop("edges", None):
+        E_in = Input(shape=(S,))
         inputs.append(E_in)
         input_data.append(E_single)
 
@@ -168,7 +213,7 @@ def _test_single_mode(layer, **kwargs):
 
     output = model(input_data)
 
-    assert output.shape == (N, kwargs['channels'])
+    assert output.shape == (N, kwargs["channels"])
 
 
 def _test_batch_mode(layer, **kwargs):
@@ -180,7 +225,7 @@ def _test_batch_mode(layer, **kwargs):
     inputs = [X_in, A_in]
     input_data = [X_batch, A_batch]
 
-    if kwargs.pop('edges', None):
+    if kwargs.pop("edges", None):
         E_batch = np.stack([E] * batch_size)
         E_in = Input(shape=(N, N, S))
         inputs.append(E_in)
@@ -192,11 +237,11 @@ def _test_batch_mode(layer, **kwargs):
 
     output = model(input_data)
 
-    assert output.shape == (batch_size, N, kwargs['channels'])
+    assert output.shape == (batch_size, N, kwargs["channels"])
 
 
 def _test_mixed_mode(layer, **kwargs):
-    sparse = kwargs.pop('sparse', False)
+    sparse = kwargs.pop("sparse", False)
     X_batch = np.stack([X] * batch_size)
     A_in = Input(shape=(N,), sparse=sparse)
     X_in = Input(shape=(N, F))
@@ -206,50 +251,54 @@ def _test_mixed_mode(layer, **kwargs):
     else:
         input_data = [X_batch, A]
 
+    if kwargs.pop("edges", None):
+        E_in = Input(
+            shape=(
+                N * N,
+                S,
+            )
+        )
+        inputs.append(E_in)
+        E_batch = np.stack([E_single] * batch_size)
+        input_data.append(E_batch)
+
     layer_instance = layer(**kwargs)
     output = layer_instance(inputs)
     model = Model(inputs, output)
 
     output = model(input_data)
 
-    assert output.shape == (batch_size, N, kwargs['channels'])
+    assert output.shape == (batch_size, N, kwargs["channels"])
 
 
 def _test_get_config(layer, **kwargs):
-    if kwargs.get('edges'):
-        kwargs.pop('edges')
+    if kwargs.get("edges"):
+        kwargs.pop("edges")
     layer_instance = layer(**kwargs)
     config = layer_instance.get_config()
     layer_instance_new = layer(**config)
     config_new = layer_instance_new.get_config()
-    config.pop('name')
-    config_new.pop('name')
+    config.pop("name")
+    config_new.pop("name")
 
     # Remove 'name' if we have advanced activations (needed for GeneralConv)
-    if 'activation' in config and 'class_name' in config['activation']:
-        config['activation']['config'].pop('name')
-        config_new['activation']['config'].pop('name')
+    if "activation" in config and "class_name" in config["activation"]:
+        config["activation"]["config"].pop("name")
+        config_new["activation"]["config"].pop("name")
 
     assert config_new == config
 
 
 def test_layers():
     for test in TESTS:
+        sparse = test[KWARGS_K_]["sparse_support"]
         for mode in test[MODES_K_]:
             if mode == SINGLE:
-                if 'sparse' in test[KWARGS_K_]:
-                    sparse = test[KWARGS_K_].pop('sparse')
-                    for s in sparse:
-                        _test_single_mode(test[LAYER_K_], sparse=s, **test[KWARGS_K_])
-                else:
-                    _test_single_mode(test[LAYER_K_], **test[KWARGS_K_])
+                for s in sparse:
+                    _test_single_mode(test[LAYER_K_], sparse=s, **test[KWARGS_K_])
             elif mode == BATCH:
                 _test_batch_mode(test[LAYER_K_], **test[KWARGS_K_])
             elif mode == MIXED:
-                if 'sparse' in test[KWARGS_K_]:
-                    sparse = test[KWARGS_K_].pop('sparse')
-                    for s in sparse:
-                        _test_mixed_mode(test[LAYER_K_], sparse=s, **test[KWARGS_K_])
-                else:
-                    _test_mixed_mode(test[LAYER_K_], **test[KWARGS_K_])
+                for s in sparse:
+                    _test_mixed_mode(test[LAYER_K_], sparse=s, **test[KWARGS_K_])
         _test_get_config(test[LAYER_K_], **test[KWARGS_K_])
